@@ -15,13 +15,17 @@ var rjs_config = {
   paths: {
     underscore : 'components/underscore/underscore-min',
     backbone : 'components/backbone/backbone-min',
+    jed: 'components/jed/jed',
     jquery: 'components/jquery/jquery.min',
+    json: 'components/requirejs-plugins/src/json',
+    text: 'components/requirejs-text/text',
     bootstrap: 'components/bootstrap/js/bootstrap.min',
     bootstraptour: 'components/bootstrap-tour/build/js/bootstrap-tour.min',
-    "jquery-ui": 'components/jquery-ui/ui/minified/jquery-ui.min',
-    moment: 'components/moment/moment',
+    "jquery-ui": 'components/jquery-ui/jquery-ui.min',
+    moment: 'components/moment/min/moment-with-locales',
     codemirror: 'components/codemirror',
-    termjs: 'components/xterm.js/dist/xterm',
+    xterm: 'components/xterm.js/index',
+    'xtermjs-fit': 'components/xterm.js-fit/index',
     typeahead: 'components/jquery-typeahead/dist/jquery.typeahead',
     contents: 'empty:',
     custom: 'empty:',
@@ -54,7 +58,7 @@ var rjs_config = {
     "jquery-ui": {
       deps: ["jquery"],
       exports: "$"
-    }
+    },
   },
 
   exclude: [
